@@ -24,7 +24,7 @@ class IPX800:
         request_timeout: int = 5,
         session: aiohttp.client.ClientSession = None,
     ) -> None:
-        """Init a IPX800v4 API."""
+        """Init a IPX800 V5 API."""
         self.host = host
         self.port = port
         self._api_key = api_key
@@ -148,12 +148,13 @@ class IPX800:
     async def global_get(self) -> dict:
         """Get all values from the IPX800 API."""
         values = await self._request_api("core/io")
-        values.update(self._request_api("core/ana"))
+        values.update(await self._request_api("core/ana"))
         return values
 
     def get_ext_id(self, ext_type, ext_number) -> str:
         """Return the unique extension id generated by the IPX."""
-        extensions = [x for x in self.extensions_config if x["type"] == ext_type]
+        extensions = [
+            x for x in self.extensions_config if x["type"] == ext_type]
         return extensions[ext_number - 1]["id"]
         # TODO Raise error if extension not existing ? or return empty str
 
@@ -168,7 +169,8 @@ class IPX800:
         )
         if ext_type == IPX:
             return self._ipx_config[id_key][output_number - 1]
-        extensions = [x for x in self.extensions_config if x["type"] == ext_type]
+        extensions = [
+            x for x in self.extensions_config if x["type"] == ext_type]
         if output_number is None:
             return extensions[ext_number - 1][EXT_CONFIG_PARAMS][id_key]
         return extensions[ext_number - 1][EXT_CONFIG_PARAMS][id_key][output_number - 1]
@@ -184,11 +186,20 @@ class IPX800:
         )
         if ext_type == IPX:
             return self._ipx_config[id_key][output_number - 1]
-        extensions = [x for x in self.extensions_config if x["type"] == ext_type]
+        extensions = [
+            x for x in self.extensions_config if x["type"] == ext_type]
         if output_number is None:
             return extensions[ext_number - 1][EXT_CONFIG_PARAMS][id_key]
         return extensions[ext_number - 1][EXT_CONFIG_PARAMS][id_key][output_number - 1]
 
+    def get_xthl_ids(
+            self, ext_number) -> list:
+        """Return the unique id of X-THL inputs in temp,hum,lum order."""
+        extensions = [
+            x for x in self.extensions_config if x["type"] == EXT_XTHL]
+        params = extensions[ext_number - 1][EXT_CONFIG_PARAMS]
+        return [params["anaTemp_id"], params["anaHum_id"], params["anaLum_id"]]
+
     def get_command_id(
         self, ext_type, ext_number, command_type, command_number=None
     ) -> str:
@@ -200,7 +211,8 @@ class IPX800:
         )
         if ext_type == IPX:
             return self._ipx_config[id_key][command_number - 1]
-        extensions = [x for x in self.extensions_config if x["type"] == ext_type]
+        extensions = [
+            x for x in self.extensions_config if x["type"] == ext_type]
         if command_number is None:
             return extensions[ext_number - 1][EXT_CONFIG_PARAMS][id_key]
         return extensions[ext_number - 1][EXT_CONFIG_PARAMS][id_key][command_number - 1]
